; This is version
; 0.04
; Maintainer: Bernd Nowak
; You need the Inno Setup Quickpack to use it.
; Homepage: http://www.jrsoftware.org/isinfo.php
; Download: http://files.jrsoftware.org/ispack/ispack-5.2.2.exe
;
; History
; Original version released to the public
; 0.01
; 0.02
; Changed only the ModInstallerReadme.txt
; to give Inno Setup the well deserved mention
; 0.03
; Added the empty folders games\battles and
; games\save to avoid different saved games which will get mixed up and cause crashes etc.
; 0.04
; Added a folder customexe as well as a key customExe in the install.ini file
; If there's an entry in the install.ini file AND the file is found in the
; customexe directory the file will be copied and the shortcuts will be set to this
; exe file.

#define moddir ReadIni(".\edits\install.ini","installinfo", "modDirectory")
#define dialogtitle ReadIni(".\edits\install.ini","installinfo", "dialogTitle")
#define name ReadIni(".\edits\install.ini","installinfo", "name")
#define author ReadIni(".\edits\install.ini","installinfo", "author")
#define version ReadIni(".\edits\install.ini","installinfo", "version")
#define customexe ReadIni(".\edits\install.ini","installinfo","customExe")

#if "" == version
#define version "1.00"
#endif
#if "" == author
#define author "Close Combat WaR Mod Installer"
#endif
#define screenshot "false"
#if fileexists(".\edits\screenshot.bmp")
#define screenshot "true"
#endif

; Additional checks and messages to help
#if "" == modDir
#error You must fill in a value for modDirectory in the .\edits\INSTALL.INI file before compiling. This is mandatory !
#endif

#if "" == dialogtitle
#error You must fill in a value for dialogtitle in the .\edits\INSTALL.INI file before compiling. This is mandatory !
#endif

#if "" == name
#error You must fill in a value for name in the .\edits\INSTALL.INI file before compiling. This is mandatory !
#endif

#if "CCE.exe" == customexe
#error Please choose another name for your EXE file because CCE.exe would overwrite the original !!!
#endif

[Setup]
OutputBaseFilename=CCWaRModInstall{#moddir}v{#version}
AppCopyright={#author}
AppName={#name}
AppVerName={#name}
DefaultDirName={code:GetDefaultPathRegistry|'C:\Matrix Games\Close Combat Wacht am Rhein'}
UsePreviousAppDir=false
DirExistsWarning=no
AllowUNCPath=false
AppendDefaultDirName=false
DisableProgramGroupPage=true
UsePreviousGroup=false
ShowLanguageDialog=no
SetupIconFile=.\edits\modinstaller.ico
WizardImageFile=.\edits\WizardLeftImage.bmp
WizardSmallImageFile=.\edits\WizardSmallImage.bmp
Compression=lzma/ultra
Uninstallable=true
UninstallDisplayName={#name}
UninstallFilesDir={app}\mods\{#name}
VersionInfoVersion={#version}
VersionInfoCompany={#author}
VersionInfoDescription={#name}
VersionInfoTextVersion={#name}
VersionInfoCopyright={#author}
PrivilegesRequired=admin
DefaultGroupName=Close Combat Wacht am Rhein\{#name}

[Tasks]
Name: desktopicon; Description: Create a &desktop icon; GroupDescription: Additional icons:

[Icons]
#if FileExists("customexe\" + customexe)
Name: {group}\Launch {#name}; Filename: {app}\{#customexe}; Parameters: " /D {#moddir}"; WorkingDir: {app}; IconFilename: {app}\{#moddir}\mod.ico; IconIndex: 0
Name: {userdesktop}\Launch {#name}; Filename: {app}\{#customexe}; Tasks: desktopicon; Parameters: " /D {#moddir}"; WorkingDir: {app}; IconFilename: {app}\{#moddir}\mod.ico; IconIndex: 0
#else
Name: {group}\Launch {#name}; Filename: {app}\CCe.exe; Parameters: " /D {#moddir}"; WorkingDir: {app}; IconFilename: {app}\{#moddir}\mod.ico; IconIndex: 0
Name: {userdesktop}\Launch {#name}; Filename: {app}\CCe.exe; Tasks: desktopicon; Parameters: " /D {#moddir}"; WorkingDir: {app}; IconFilename: {app}\{#moddir}\mod.ico; IconIndex: 0
#endif

[Files]
Source: edits\readme.txt; DestDir: {app}\{#moddir}; Flags: overwritereadonly ignoreversion isreadme
Source: edits\mod.ico; DestDir: {app}\{#moddir}; Flags: overwritereadonly ignoreversion
Source: mod\*.*; DestDir: {app}\{#moddir}; Flags: overwritereadonly ignoreversion recursesubdirs createallsubdirs
#ifexist "edits\screenshot.bmp"
Source: edits\screenshot.bmp; DestDir: {tmp}; Flags: dontcopy
#else
Source: noscreenshot.bmp; DestDir: {tmp}; Flags: dontcopy
#endif
#if FileExists("customexe\" + customexe)
Source: customexe\{#customexe}; DestDir: {app}; Flags: overwritereadonly ignoreversion
#endif

[Registry]
Root: HKLM; Subkey: SOFTWARE\CCWaR\Mods; ValueType: string; ValueName: CCWaRPath; ValueData: {app}; Flags: deletevalue noerror; Components: 

[CustomMessages]
modinstallchoices_Caption=Please choose your options
modinstallchoices_Description=Adjust the setup and read the notes
checkccWaR=No CCE.exe found in your destination directory ! Please select a valid destination directory

[Messages]
AdminPrivilegesRequired=The Installer needs Admin rights !

SetupWindowTitle={#dialogtitle}
SetupAppTitle={#name}
WelcomeLabel1={#name}
WelcomeLabel2=This will install/update CCWaR Mod: {#name} {#version} on your computer.%n%nIt is recommended that you close all other applications before continuing.
WizardSelectDir=Select your CCWaR directory (usually C:\Matrix Games\Close Combat Wacht am Rhein)
SelectDirLabel3=The CCWaR Mod Installer will add/update {#name} {#version} to the following selected CCWaR Installation.
SelectDirBrowseLabel=To continue, click Next. If you would like to select a different CCWaR Installation, click Browse.
SelectDirDesc=Where is your Close Combat Wacht am Rhein Base Directory ?

[Code]

function GetDefaultPathRegistry(DefaultPath: string): string;
begin
	if not RegQueryStringValue(HKLM,'SOFTWARE\CCWaR\Mods','CCWaRPath',Result) then
	begin
	 if not RegQueryStringValue(HKLM,'SOFTWARE\Matrix Games\Close Combat Wacht am Rhein','installed to',Result) then
	 begin
	   Result := ExpandConstant(DefaultPath);
	 end;
	end;
end;

function InitializeSetup(): Boolean;
begin
	// Msgbox('Screenshot: {#screenshot}',mbInformation,MB_OK);
	if '{#screenshot}' = 'true' then
	begin
		ExtractTemporaryFile('screenshot.bmp');
	end
	else
	begin
		ExtractTemporaryFile('noscreenshot.bmp');
	end
	ExtractTemporaryFile('readme.txt');
	result :=true;
end;


function checkmoddir():boolean;
var
	moddir : String;

begin
	result :=false;
	moddir := ExpandConstant('{app}')+'\{#moddir}';
	// Check if moddir exist
	if DirExists(moddir) then
	begin
		if msgbox('It looks like the mod has been installed because the installer found this moddir:' + #13 + moddir + #13 + 'depending on your choosen CCWaR directory !' + #13 + 'Do you want to adjust your CCWaR directory ?',mbConfirmation, MB_YESNO or MB_DEFBUTTON1)= IDYES then
		begin
		result:=true;
		end;
	end;
end;


procedure CurStepChanged(CurStep: TSetupStep);

begin
	case CurStep of
        ssPostInstall:
        begin
        //
		end;
	end;
end;

function CheckCCWaR(Path: String):Boolean;

begin
Result:= FileExists(Path + '\CCE.EXE');
	// MsgBox('File to check: ' + Path + '\CCe
	if not Result then  MsgBox(ExpandConstant('{cm:checkccWaR}'), mbInformation, MB_OK)
end;


function NextButtonClick(CurPageID: Integer): boolean;
begin

result:=true;
	if CurPageID=wpSelectDir then
	begin
	 // Check for CCE.exe in selected directory
    if not CheckCCWaR(WizardDirValue) then
    begin
      result:=false;
			exit;
		end;
		// if moddir is existing make a small warning
		if checkmoddir then
		begin
			result:=false;
			exit;
		end;
  end;
end;

procedure InitializeWizard();
begin
  // trackinstallchoices_CreatePage(wpSelectDir);
end;
